@@ -50,6 +50,8 @@ class JobStore(object):
 
     def add_job(self, job):
         with self.rw_lock:
+            if self.has_job(job.name):
+                self.remove_job(job.name)
             self.jobs[job.name] = job
             job.start()
 
@@ -64,8 +66,9 @@ class JobStore(object):
 
     def remove_job(self, name):
         with self.rw_lock:
-            job = self.jobs.pop(name)
-            job.stop()
+            if self.has_job(name):
+                job = self.jobs.pop(name)
+                job.stop()
 
 
 class Scheduler(object):
@@ -101,8 +104,8 @@ class Scheduler(object):
     def is_job_scheduled(self, job_name):
         return self.store.has_job(job_name)
 
-    def remove_job(self, job):
-        job_name = self._job_name(job)
+    def remove_job(self, job_inst_or_name):
+        job_name = self._job_name(job_inst_or_name)
         self.store.remove_job(job_name)
 
     def stop(self):
